NAME = "blue_flie"

ICON = "🦋"

DESCRIPTION = f"{ICON} flying with AI."

VERSION = "4.5.1"

REPO_NAME = "blue-flie"

MARQUEE = "https://github.com/kamangir/assets/raw/main/blue-flie/marquee.png?raw=true"

ALIAS = "@flie"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
